@@ -45,7 +45,9 @@
 #    include <fcntl.h>
 
 #    include <stdlib.h>
-#    include <malloc.h>
+#    if !defined(STDC_HEADERS) && defined(HAVE_MALLOC_H)
+#	 include <malloc.h>
+#    endif
 
 #else       /* ! MIDNIGHT */
 
@@ -379,6 +381,8 @@ void edit_push_action (WEdit * edit, long c,...);
 void edit_push_key_press (WEdit * edit);
 void edit_insert_ahead (WEdit * edit, int c);
 int edit_save_file (WEdit * edit, const char *filename);
+long edit_write_stream (WEdit * edit, FILE * f);
+char *edit_get_write_filter (char *writename, const char *filename);
 int edit_save_cmd (WEdit * edit);
 int edit_save_confirm_cmd (WEdit * edit);
 int edit_save_as_cmd (WEdit * edit);
@@ -394,6 +398,7 @@ void edit_push_markers (WEdit * edit);
 void edit_quit_cmd (WEdit * edit);
 void edit_replace_cmd (WEdit * edit, int again);
 void edit_search_cmd (WEdit * edit, int again);
+int edit_save_block (WEdit * edit, const char *filename, long start, long finish);
 int edit_save_block_cmd (WEdit * edit);
 int edit_insert_file_cmd (WEdit * edit);
 int edit_insert_file (WEdit * edit, const char *filename);
@@ -429,7 +434,7 @@ void edit_paste_from_X_buf_cmd (WEdit * edit);
 
 void edit_paste_from_history (WEdit *edit);
 
-void edit_split_filename (WEdit * edit, char *name);
+void edit_split_filename (WEdit * edit, const char *name);
 
 #ifdef MIDNIGHT
 #define CWidget Widget
@@ -454,7 +459,6 @@ void book_mark_dec (WEdit * edit, int line);
 
 void user_menu (WEdit *edit);
 
-
 #ifdef MIDNIGHT
 
 #define CPushFont(x,y)
