@@ -4,6 +4,8 @@
 
    Authors: 1996, 1997 Paul Sheer
 
+   $Id: editcmd.c,v 1.31 2001/02/26 19:51:56 proskin Exp $
+
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
@@ -18,6 +20,7 @@
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
    02111-1307, USA.
+
 */
 
 /* #define PIPE_BLOCKS_SO_READ_BYTE_BY_BYTE */
@@ -69,7 +72,7 @@ static inline int my_lower_case (int c)
 
 char *strcasechr (const unsigned char *s, int c)
 {
-    for (; my_lower_case ((int) *s) != my_lower_case (c); ++s)
+    for (c = my_lower_case (c); my_lower_case ((int) *s) != c; ++s)
 	if (*s == '\0')
 	    return 0;
     return (char *) s;
@@ -162,7 +165,7 @@ char *catstrs (const char *first,...)
 
 void edit_help_cmd (WEdit * edit)
 {
-    char *hlpdir = concat_dir_and_file (mc_home, "mc.hlp");
+    char *hlpdir = concat_dir_and_file (mc_home, _("mc.hlp"));
     interactive_display (hlpdir, "[Internal File Editor]");
     free (hlpdir);
     edit->force |= REDRAW_COMPLETELY;
@@ -179,12 +182,12 @@ void edit_refresh_cmd (WEdit * edit)
 	edit_get_syntax_color (edit, -1, &fg, &bg);
     }
     touchwin(stdscr);
-#endif
+#endif	/* !HAVE_SLANG */
     mc_refresh();
     doupdate();
 }
 
-#else
+#else /* MIDNIGHT */
 
 void edit_help_cmd (WEdit * edit)
 {
@@ -202,7 +205,7 @@ void CRefreshEditor (WEdit * edit)
     edit_refresh_cmd (edit);
 }
 
-#endif
+#endif /* MIDNIGHT */
 
 #ifndef MIDNIGHT
 #ifndef GTK
@@ -227,8 +230,8 @@ int my_open (const char *pathname, int flags,...)
 
 #define open my_open
 
-#endif
-#endif
+#endif /* !GTK */
+#endif /* !MIDNIGHT */
 
 /* "Oleg Yu. Repin" <repin@ssd.sscc.ru> added backup filenames
     ...thanks -paul */
@@ -246,7 +249,6 @@ int edit_save_file (WEdit * edit, const char *filename)
 {
     char *p;
     long filelen = 0;
-    FILE *file;
     char *savename = 0;
     int this_save_mode, fd;
 
@@ -278,23 +280,28 @@ int edit_save_file (WEdit * edit, const char *filename)
 	savename = (char *) tempnam (savedir, "cooledit");
 	free (savedir);
 	if (!savename)
-	    goto error_save;
+	    return 0;
     }
-    if ((file = fopen (savename, "w+")) == 0)
+
+    if ((fd = open (savename, O_CREAT | O_WRONLY | O_TRUNC | MY_O_TEXT, edit->stat.st_mode)) == -1)
 	goto error_save;
+
     chmod (savename, edit->stat.st_mode);
     chown (savename, edit->stat.st_uid, edit->stat.st_gid);
 
 /* pipe save */
     if ((p = (char *) edit_get_write_filter (savename, filename))) {
-	fclose (file);
-	file = (FILE *) popen (p, "w");
+	FILE *file;
+
+	close (fd);
+	file  = (FILE *) popen (p, "w");
+
 	if (file) {
 	    filelen = edit_write_stream (edit, file);
 #if 1
 	    pclose (file);
 #else
-	    if (pclose (file) > 0) {
+	    if (pclose (file) != 0) {
 		edit_error_dialog (_ (" Error "), catstrs (_ (" Error writing to pipe: "), p, " ", 0));
 		free (p);
 		goto error_save;
@@ -309,40 +316,40 @@ int edit_save_file (WEdit * edit, const char *filename)
 #ifdef CR_LF_TRANSLATION
     } else {			/* optimised save */
 	filelen = edit_write_stream (edit, f);
-	fclose (file);
+	if (fclose (file))
+	    filelen = -1;
 #else
     } else {
 	long buf;
 	buf = 0;
 	filelen = edit->last_byte;
 	while (buf <= (edit->curs1 >> S_EDIT_BUF_SIZE) - 1) {
-	    if (fwrite ((char *) edit->buffers1[buf], EDIT_BUF_SIZE, 1, file) != 1) {
-		filelen = -1;
-		break;
+	    if (write (fd, (char *) edit->buffers1[buf], EDIT_BUF_SIZE) != EDIT_BUF_SIZE) {
+		close (fd);
+		goto error_save;
 	    }
 	    buf++;
 	}
-	if (fwrite ((char *) edit->buffers1[buf], edit->curs1 & M_EDIT_BUF_SIZE, 1, file) == -1) {
+	if (write (fd, (char *) edit->buffers1[buf], edit->curs1 & M_EDIT_BUF_SIZE) != (edit->curs1 & M_EDIT_BUF_SIZE)) {
 	    filelen = -1;
 	} else if (edit->curs2) {
 	    edit->curs2--;
 	    buf = (edit->curs2 >> S_EDIT_BUF_SIZE);
-	    if (fwrite ((char *) edit->buffers2[buf] + EDIT_BUF_SIZE - (edit->curs2 & M_EDIT_BUF_SIZE) - 1, 1 + (edit->curs2 & M_EDIT_BUF_SIZE), 1, file) != 1) {
+	    if (write (fd, (char *) edit->buffers2[buf] + EDIT_BUF_SIZE - (edit->curs2 & M_EDIT_BUF_SIZE) - 1, 1 + (edit->curs2 & M_EDIT_BUF_SIZE)) !=  1 + (edit->curs2 & M_EDIT_BUF_SIZE)) {
 		filelen = -1;
 	    } else {
-		buf--;
-		while (buf >= 0) {
-		    if (fwrite ((char *) edit->buffers2[buf], EDIT_BUF_SIZE, 1, file) != 1) {
+		while (--buf >= 0) {
+		    if (write (fd, (char *) edit->buffers2[buf], EDIT_BUF_SIZE) != EDIT_BUF_SIZE) {
 			filelen = -1;
 			break;
 		    }
-		    buf--;
 		}
 	    }
 	    edit->curs2++;
 	}
-	fclose (file);
-#endif
+	if (close (fd))
+	    goto error_save;
+#endif	/* CR_LF_TRANSLATION */
     }
 
     if (filelen != edit->last_byte)
@@ -393,7 +400,6 @@ void menu_save_mode_cmd (void)
 	 0, &save_mode_new, str, XV_WLAY_DONTCARE, "t"},
 	{0}};
     static QuickDialog dialog =
-/* NLS ? */
     {DLG_X, DLG_Y, -1, -1, N_(" Edit Save Mode "), "[Edit Save Mode]",
      "esm", widgets};
     static int i18n_flag = 0;
@@ -417,11 +423,7 @@ void menu_save_mode_cmd (void)
     memcpy ((char *) &option_backup_ext_int, str_result, strlen (option_backup_ext));
 }
 
-#endif
-
-#ifdef MIDNIGHT
-
-void edit_split_filename (WEdit * edit, char *f)
+void edit_split_filename (WEdit * edit, const char *f)
 {
     if (edit->filename)
 	free (edit->filename);
@@ -431,15 +433,16 @@ void edit_split_filename (WEdit * edit, char *f)
     edit->dir = (char *) strdup ("");
 }
 
-#else
+#else	/* MIDNIGHT */
 
 #ifdef GTK
 
 static char cwd[1040];
 
-static char *canonicalize_pathname (char *p)
+static char *canonicalize_pathname (const char *p)
 {
     char *q, *r;
+    char *t = NULL;
 
     if (*p != '/') {
 	if (strlen (cwd) == 0) {
@@ -449,18 +452,14 @@ static char *canonicalize_pathname (char *p)
 	    getwd (cwd);
 #endif
 	}
-	r = malloc (strlen (cwd) + strlen (p) + 2);
-	strcpy (r, cwd);
-	strcat (r, "/");
-	strcat (r, p);
-	p = r;
+	t = malloc (strlen (cwd) + strlen (p) + 2);
+	strcpy (t, cwd);
+	strcat (t, "/");
+	strcat (t, p);
+	p = t;
     }
     r = q = malloc (strlen (p) + 2);
-    for (;;) {
-	if (!*p) {
-	    *q = '\0';
-	    break;
-	}
+    while (*p) {
 	if (*p != '/') {
 	    *q++ = *p++;
 	} else {
@@ -482,6 +481,9 @@ static char *canonicalize_pathname (char *p)
 	    q++;
 	}
     }
+    if (t)
+	free (t);
+    *q = '\0';
 /* get rid of trailing / */
     if (r[0] && r[1])
 	if (*--q == '/')
@@ -492,10 +494,10 @@ static char *canonicalize_pathname (char *p)
 #endif		/* GTK */
 
 
-void edit_split_filename (WEdit * edit, char *longname)
+void edit_split_filename (WEdit * edit, const char *longname)
 {
     char *exp, *p;
-#if defined(MIDNIGHT) || defined(GTK)
+#ifdef	GTK
     exp = canonicalize_pathname (longname);
 #else
     exp = pathdup (longname);	/* this ensures a full path */
@@ -619,7 +621,7 @@ int edit_raw_key_query (char *heading, char *query, int cancel)
     return w;
 }
 
-#else
+#else /* MIDNIGHT */
 
 int edit_raw_key_query (char *heading, char *query, int cancel)
 {
@@ -631,7 +633,7 @@ int edit_raw_key_query (char *heading, char *query, int cancel)
 #endif
 }
 
-#endif
+#endif /* MIDNIGHT */
 
 /* creates a macro file if it doesn't exist */
 static FILE *edit_open_macro_file (const char *r)
@@ -691,7 +693,7 @@ int edit_delete_macro (WEdit * edit, int k)
 	return 1;
     }
     for (;;) {
-	n = fscanf (f, _("key '%d 0': "), &s);
+	n = fscanf (f, ("key '%d 0': "), &s);
 	if (!n || n == EOF)
 	    break;
 	n = 0;
@@ -699,12 +701,12 @@ int edit_delete_macro (WEdit * edit, int k)
 	    n++;
 	fscanf (f, ";\n");
 	if (s != k) {
-	    fprintf (g, _("key '%d 0': "), s);
+	    fprintf (g, ("key '%d 0': "), s);
 	    for (i = 0; i < n; i++)
 		fprintf (g, "%hd %hd, ", macro[i].command, macro[i].ch);
 	    fprintf (g, ";\n");
 	}
-    };
+    }
     fclose (f);
     fclose (g);
     if (rename (catstrs (home_dir, TEMP_FILE, 0), catstrs (home_dir, MACRO_FILE, 0)) == -1) {
@@ -735,7 +737,7 @@ int edit_save_macro_cmd (WEdit * edit, struct macro macro[], int n)
 	    return 0;
 	f = edit_open_macro_file ("a+");
 	if (f) {
-	    fprintf (f, _("key '%d 0': "), s);
+	    fprintf (f, ("key '%d 0': "), s);
 	    for (i = 0; i < n; i++)
 		fprintf (f, "%hd %hd, ", macro[i].command, macro[i].ch);
 	    fprintf (f, ";\n");
@@ -757,7 +759,8 @@ void edit_delete_macro_cmd (WEdit * edit)
     int command;
 
 #ifdef MIDNIGHT
-    command = CK_Macro (edit_raw_key_query (_ (" Delete Macro "), _ (" Press macro hotkey: "), 1));
+    command = edit_raw_key_query (_ (" Delete Macro "),
+				  _ (" Press macro hotkey: "), 1);
 #else
 /* This heads the 'Delete Macro' dialog box */
 #ifdef GTK
@@ -790,7 +793,7 @@ int edit_load_macro_cmd (WEdit * edit, struct macro macro[], int *n, int k)
 	struct macro dummy;
 	do {
 	    int u;
-	    u = fscanf (f, _("key '%d 0': "), &s);
+	    u = fscanf (f, ("key '%d 0': "), &s);
 	    if (!u || u == EOF)
 		break;
 	    if (!saved_macros_loaded)
@@ -1185,7 +1188,6 @@ int edit_replace_prompt (WEdit * edit, char *replace_text, int xpos, int ypos)
 {
     QuickWidget quick_widgets[] =
     {
-/* NLS  for hotkeys? */
 	{quick_button, 63, CONFIRM_DLG_WIDTH, 3, CONFIRM_DLG_HEIGTH, N_ ("&Cancel"),
 	 0, B_CANCEL, 0, 0, XV_WLAY_DONTCARE, NULL},
 	{quick_button, 50, CONFIRM_DLG_WIDTH, 3, CONFIRM_DLG_HEIGTH, N_ ("o&Ne"),
@@ -1210,6 +1212,12 @@ int edit_replace_prompt (WEdit * edit, char *replace_text, int xpos, int ypos)
 	Quick_input.widgets = quick_widgets;
 
 	Quick_input.xpos = xpos;
+
+	/* Sometimes menu can hide replaced text. I don't like it */
+
+	if ((edit->curs_row >= ypos) && (edit->curs_row <= ypos + CONFIRM_DLG_HEIGTH))
+	    ypos -= CONFIRM_DLG_HEIGTH;
+
 	Quick_input.ypos = ypos;
 	return quick_dialog (&Quick_input);
     }
@@ -2166,7 +2174,11 @@ void edit_replace_cmd (WEdit * edit, int again)
 		edit_push_key_press (edit);
 
 		switch (edit_replace_prompt (edit, exp2,	/*and prompt 2/3 down */
+#ifdef	MIDNIGHT
+					     (edit->num_widget_columns - CONFIRM_DLG_WIDTH)/2, edit->num_widget_lines * 2 / 3)) {
+#else
 					     edit->num_widget_columns / 2 - 33, edit->num_widget_lines * 2 / 3)) {
+#endif
 		case B_ENTER:
 		    break;
 		case B_SKIP_REPLACE:
@@ -2743,8 +2755,8 @@ void edit_goto_cmd (WEdit *edit)
 	    edit_move_display (edit, l - edit->num_widget_lines / 2 - 1);
 	    edit_move_to_line (edit, l - 1);
 	    edit->force |= REDRAW_COMPLETELY;
-	    free (f);
 	}
+	free (f);
     }
 }
 
@@ -2769,8 +2781,6 @@ int edit_save_block_cmd (WEdit * edit)
 	    } else {
 		free (exp);
 		edit_error_dialog (_ (" Save Block "), get_sys_error (_ (" Error trying to save file. ")));
-		edit->force |= REDRAW_COMPLETELY;
-		return 0;
 	    }
 	}
     }
@@ -2796,8 +2806,6 @@ int edit_insert_file_cmd (WEdit * edit)
 	    } else {
 		free (exp);
 		edit_error_dialog (_ (" Insert file "), get_sys_error (_ (" Error trying to insert file. ")));
-		edit->force |= REDRAW_COMPLETELY;
-		return 0;
 	    }
 	}
     }
@@ -2816,7 +2824,6 @@ int edit_sort_cmd (WEdit * edit)
     int e;
 
     if (eval_marks (edit, &start_mark, &end_mark)) {
-/* Not essential to translate */
 	edit_error_dialog (_(" Sort block "), _(" You must first highlight a block of text. "));
 	return 0;
     }
@@ -2825,8 +2832,7 @@ int edit_sort_cmd (WEdit * edit)
     exp = old ? old : "";
 
     exp = input_dialog (_(" Run Sort "), 
-/* Not essential to translate */
-    _(" Enter sort options (see manpage) separated by whitespace: "), "");
+    _(" Enter sort options (see manpage) separated by whitespace: "), exp);
 
     if (!exp)
 	return 1;
@@ -2838,13 +2844,11 @@ int edit_sort_cmd (WEdit * edit)
     if (e) {
 	if (e == -1 || e == 127) {
 	    edit_error_dialog (_(" Sort "), 
-/* Not essential to translate */
 	    get_sys_error (_(" Error trying to execute sort command ")));
 	} else {
 	    char q[8];
 	    sprintf (q, "%d ", e);
 	    edit_error_dialog (_(" Sort "), 
-/* Not essential to translate */
 	    catstrs (_(" Sort returned non-zero: "), q, 0));
 	}
 	return -1;
@@ -2877,25 +2881,25 @@ void edit_block_process_cmd (WEdit * edit, const char *shell_cmd, int block)
     
     if (! (script_home = fopen (h, "r"))) {
 	if (! (script_home = fopen (h, "w"))) {
-	    edit_error_dialog (_(""),
+	    edit_error_dialog ("",
             get_sys_error (catstrs (_ ("Error create script:"), h, 0)));
             return;
 	} else {
 	    if (! (script_src = fopen (o, "r"))) {
                 fclose (script_home); unlink (h);
-	        edit_error_dialog (_(""),
+	        edit_error_dialog ("",
                 get_sys_error (catstrs (_ ("Error read script:"), o, 0)));
                 return;
             } else {    
                 while (fgets(buf, sizeof(buf), script_src))
-	                fprintf(script_home, "%s",buf);
+		    fputs (buf, script_home);
                 if (fclose(script_home)) {
-	            edit_error_dialog (_(""),
+	            edit_error_dialog ("",
                     get_sys_error (catstrs (_ ("Error close script:"), h, 0)));
                     return;
                 } else {
                     chmod (h, 0700);
-	            edit_error_dialog (_(""),
+	            edit_error_dialog ("",
                     get_sys_error (catstrs (_ ("Script created:"), h, 0)));
                 }
 	    }
@@ -2904,7 +2908,6 @@ void edit_block_process_cmd (WEdit * edit, const char *shell_cmd, int block)
     if (block) { /* for marked block run indent formatter */
 	if (eval_marks (edit, &start_mark, &end_mark)) {
 	    edit_error_dialog (_("Process block"),
-/* Not essential to translate */
 		_(" You must first highlight a block of text. "));
 	    return;
 	}
@@ -2916,14 +2919,13 @@ void edit_block_process_cmd (WEdit * edit, const char *shell_cmd, int block)
 	    edit->filename, " ", home_dir, BLOCK_FILE, " ", 
 	    home_dir, ERROR_FILE, 0));
 
-        edit_refresh_cmd (edit);
-
     } else { /* for missing marked block run ... */
 	my_system (0, shell, catstrs (EDIT_DIR, shell_cmd));
-        edit_refresh_cmd (edit);
     }
+
+    edit_refresh_cmd (edit);
     edit->force |= REDRAW_COMPLETELY;
-    
+
     /* insert result block */ 
     if (block) {
 	if (stat (e, &s) == 0) {
@@ -2931,27 +2933,22 @@ void edit_block_process_cmd (WEdit * edit, const char *shell_cmd, int block)
 		if (edit_block_delete_cmd (edit))
 		    return;
 		edit_insert_file (edit, b);
-		if (block_file = fopen (b, "w")) fclose(block_file);
-		return;
 	    } else {
 		edit_insert_file (edit, e);
-		if (block_file = fopen (b, "w")) fclose(block_file);
-		return;
 	    }
 	} else {
-/* Not essential to translate */
-	    edit_error_dialog (_(""),
-/* Not essential to translate */
+	    edit_error_dialog ("",
             get_sys_error (catstrs (_ ("Error trying to stat file:"), e, 0)));
 	    edit->force |= REDRAW_COMPLETELY;
-	    if (block_file = fopen (b, "w")) fclose(block_file);
-	    return;
 	}
+	if ((block_file = fopen (b, "w")))
+	    fclose (block_file);
+	return;
     }
     return;
 }
 
-#endif
+#endif /* MIDNIGHT */
 
 int edit_execute_cmd (WEdit * edit, int command, int char_for_insertion);
 
@@ -2985,21 +2982,22 @@ int edit_printf (WEdit * e, const char *fmt,...)
 
 static void pipe_mail (WEdit *edit, char *to, char *subject, char *cc)
 {
-    FILE *p;
+    FILE *p = 0;
     char *s;
-    s = malloc (4096);
-    sprintf (s, "mail -s \"%s\" -c \"%s\" \"%s\"", subject, cc, to);
-    p = popen (s, "w");
-    if (!p) {
-	free (s);
-	return;
-    } else {
+
+    s = g_strdup_printf ("mail -s \"%s\" -c \"%s\" \"%s\"", subject, cc, to);
+
+    if (s) {
+	p = popen (s, "w");
+	g_free (s);
+    }
+
+    if (p) {
 	long i;
 	for (i = 0; i < edit->last_byte; i++)
 	    fputc (edit_get_byte (edit, i), p);
 	pclose (p);
     }
-    free (s);
 }
 
 #define MAIL_DLG_HEIGHT 12
@@ -3016,12 +3014,10 @@ void edit_mail_dialog (WEdit * edit)
 
     QuickDialog Quick_input =
     {50, MAIL_DLG_HEIGHT, -1, 0, N_(" Mail "),
-/* NLS ? */
      "[Input Line Keys]", "quick_input", 0};
 
     QuickWidget quick_widgets[] =
     {
-/* NLS ? */
 	{quick_button, 6, 10, 9, MAIL_DLG_HEIGHT, N_("&Cancel"), 0, B_CANCEL, 0,
 	 0, XV_WLAY_DONTCARE, NULL},
 	{quick_button, 2, 10, 9, MAIL_DLG_HEIGHT, N_("&Ok"), 0, B_ENTER, 0,
@@ -3065,5 +3061,5 @@ void edit_mail_dialog (WEdit * edit)
     }
 }
 
-#endif
+#endif /* MIDNIGHT */
 
