@@ -13,7 +13,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
 /* The cons saver can't have a pid of 1, used to prevent bunches of */
 /*#ifdef linux */
@@ -146,10 +146,12 @@ void handle_console (unsigned char action)
 	    /* Bind standard error to /dev/null */
 	    close (2);
 	    open ("/dev/null", O_WRONLY);
-	    /* Exec the console save/restore handler */
-	    mc_conssaver = concat_dir_and_file (mc_home, "bin/cons.saver");
-	    execl (mc_conssaver, "cons.saver", tty_name, NULL);
-	    /* Exec failed */
+	    if (tty_name) {
+		/* Exec the console save/restore handler */
+		mc_conssaver = concat_dir_and_file (mc_home, "bin/cons.saver");
+		execl (mc_conssaver, "cons.saver", tty_name, NULL);
+	    }
+	    /* Console is not a tty or execl() failed */
 	    console_flag = 0;
 	    write (1, &console_flag, 1);
 	    close (1);
