@@ -13,11 +13,11 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
 #include <config.h>
-/* "$Id: dlg.c,v 1.31 2000/04/14 01:19:58 timur Exp $" */
+/* "$Id: dlg.c,v 1.33 2001/01/08 18:21:37 bansz Exp $" */
 #include <string.h>
 #include <stdio.h>
 #include <ctype.h>
@@ -650,7 +650,7 @@ static INLINE void dialog_handle_key (Dlg_head *h, int d_key)
 	break;
 
     case KEY_F(1):
-        hlpfile = concat_dir_and_file (mc_home, "mc.hlp");
+        hlpfile = concat_dir_and_file (mc_home, _("mc.hlp"));
 	interactive_display (hlpfile, h->help_ctx);
         g_free (hlpfile);
 	do_refresh ();
