@@ -1,4 +1,4 @@
-#!/usr/bin/perl
+#!/usr/bin/perl -w
 # Since we use a linear search trought the block and the license and
 # the warranty are quite big, we leave them at the end of the help file,
 # the index will be consulted quite frequently, so we put it at the beginning. 
@@ -6,17 +6,17 @@
 @help_file = <>;
 
 foreach $line (@help_file){
-    if ($line =~ /\x4\[(.*)\]/ && $line !~ /\x4\[main\]/){
-	$nodes[$node_count++] = $1;
-	$line =~ s/(\x4\[) */$1/;
+    if ($line =~ /\x04\[(.*)\]/ && $line !~ /\x04\[main\]/){
+	push @nodes, $1;
+	$line =~ s/(\x04\[) */$1/;
     }
 }
 
-print "\x4[Contents]\nTopics:\n\n";
+print "\x04[Contents]\nTopics:\n\n";
 foreach $node (@nodes){
     if (length $node){
 	$node =~ m/^( *)(.*)$/;
-	printf ("  %s\x1 %s \x2%s\x3", $1, $2, $2);
+	printf ("  %s\x01 %s \x02%s\x03", $1, $2, $2);
     }
     print "\n";
 }
