@@ -16,7 +16,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  
+   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  
  */
 
 #include <config.h>
@@ -73,7 +73,7 @@
 
 #include "x.h"
 
-/* "$Id: layout.c,v 1.19 1999/11/03 12:50:54 pavel Exp $" */
+/* "$Id: layout.c,v 1.22 2000/11/14 14:00:53 andrew Exp $" */
 
 /* Controls the display of the rotating dash on the verbose mode */
 int nice_rotating_dash = 1;
@@ -184,6 +184,11 @@ static char *layout_title, *title1, *title2, *title3, *output_lines_label;
 
 static WButton *bleft_widget, *bright_widget;
 
+/* Declarations for static functions */
+#ifdef PORT_NEEDS_CHANGE_SCREEN_SIZE
+static void low_level_change_screen_size (void);
+#endif /* PORT_NEEDS_CHANGE_SCREEN_SIZE */
+
 static void _check_split (void)
 {
     if (_horizontal_split){
@@ -746,6 +751,9 @@ void setup_panels (void)
 
 void flag_winch (int dummy)
 {
+#ifdef PORT_NEEDS_CHANGE_SCREEN_SIZE
+    low_level_change_screen_size ();
+#endif /* PORT_NEEDS_CHANGE_SCREEN_SIZE */
     winch_flag = 1;
 }
 
@@ -771,7 +779,7 @@ low_level_change_screen_size (void)
 	LINES = winsz.ws_row;
 #endif
 #ifdef HAVE_SUBSHELL_SUPPORT
-	    resize_subshell ();
+	resize_subshell ();
 #endif
     }
 #endif /* TIOCGWINSZ && !SCO_FLAVOR */
@@ -852,22 +860,19 @@ void print_vfs_message (char *msg, ...)
     char str [128];
 
     va_start (ap, msg);
-    
-    g_vsnprintf (str, 126, msg, ap);
+
+    g_vsnprintf (str, sizeof (str), msg, ap);
     va_end (ap);
-    
+
     if (midnight_shutdown)
 	return;
 
     if (!message_visible || !the_hint || !the_hint->widget.parent) {
-        int i;
 
 	if (!nice_rotating_dash || (ok_to_refresh <= 0))
 	    return;
 	move (0, 0);
-	printw (str);
-	for (i=strlen(str); i<COLS-1; i++)
-	    printw (" ");
+	printw ("%-*s", COLS-1, str);
 	mc_refresh ();
 	return;
     }
@@ -947,7 +952,7 @@ void set_display_type (int num, int type)
     Widget *new_widget, *old_widget;
     WPanel  *the_other_panel;
 
-    x =y = cols = lines = 0;
+    x = y = cols = lines = 0;
     old_widget = 0;
     if (num >= MAX_VIEWS){
 	fprintf (stderr, "Could not allocate more that %d views\n", MAX_VIEWS);
