@@ -16,10 +16,13 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  
+   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  
  */
 
 #include <config.h>
+
+#ifdef LISTMODE_EDITOR
+
 #ifdef HAVE_UNISTD_H
 #   include <unistd.h>
 #endif
@@ -325,3 +328,5 @@ char *listmode_edit (char *oldlistformat)
     listmode_done ();
     return newformat;
 }
+
+#endif /* LISTMODE_EDITOR */
