@@ -17,7 +17,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
 #include <config.h>
 #include <locale.h>
@@ -122,6 +122,9 @@
 #include "command.h"
 #include "wtools.h"
 #include "complete.h"		/* For the free_completion */
+#ifndef HAVE_X
+#include "textconf.h"
+#endif
 
 #include "chmod.h"
 #include "chown.h"
@@ -147,7 +150,7 @@
 #endif
 #endif
 
-/* "$Id: main.c,v 1.113 2000/06/20 19:50:32 jberkman Exp $" */
+/* "$Id: main.c,v 1.124 2001/02/26 16:54:23 proskin Exp $" */
 
 /* When the modes are active, left_panel, right_panel and tree_panel */
 /* Point to a proper data structure.  You should check with the functions */
@@ -211,11 +214,11 @@ int   pause_after_run = pause_on_dumb_terminals;
 int auto_save_setup = 1;
 
 /* If true, be eight bit clean */
-int eight_bit_clean = 0;
+int eight_bit_clean = 1;
 
 /* If true, then display chars 0-255, else iso-8859-1,
    requires eight_bit_clean */
-int full_eight_bits = 0;
+int full_eight_bits = 1;
 
 /* If true use the internal viewer */
 int use_internal_view = 1;
@@ -1223,18 +1226,18 @@ tree_box (void)
 	g_free (sel_dir);
     }
 }
-#endif
 
-#if SOMEDAY_WE_WILL_FINISH_THIS_CODE
+#ifdef LISTMODE_EDITOR
 static void
-	listmode_cmd (void)
+listmode_cmd (void)
 {
     char *newmode;
     newmode = listmode_edit ("half <type,>name,|,size:8,|,perm:4+");
-    message (0, " Listing format edit ", " New mode is \"%s\" ", newmode);
+    message (0, _(" Listing format edit "), _(" New mode is \"%s\" "), newmode);
     g_free (newmode);
 }
-#endif
+#endif /* LISTMODE_EDITOR */
+#endif /* !HAVE_GNOME */
 
 #ifdef HAVE_GNOME
 void init_menu (void) {};
@@ -1289,6 +1292,7 @@ static menu_entry RightMenu [] = {
     { ' ', N_("&Rescan         C-r"),    'R', reread_cmd }
 };
 
+#ifndef HAVE_GNOME
 static menu_entry FileMenu [] = {
     { ' ', N_("&User menu          F2"), 'U', user_file_menu_cmd },
     { ' ', N_("&View               F3"), 'V', view_cmd },
@@ -1315,6 +1319,7 @@ static menu_entry FileMenu [] = {
     { ' ', "", ' ', 0 },
     { ' ', N_("e&Xit              F10"), 'X', (callfn) quit_cmd }
 };
+#endif
 
 void external_panelize (void);
 static menu_entry CmdMenu [] = {
@@ -1345,13 +1350,17 @@ static menu_entry CmdMenu [] = {
 #ifdef USE_EXT2FSLIB
     { ' ', N_("&Undelete files (ext2fs only)"), 'U', undelete_cmd },
 #endif
-#ifdef VERSION_4
+#ifdef LISTMODE_EDITOR
     { ' ', N_("&Listing format edit"),          'L', listmode_cmd},
 #endif
+#if defined (USE_EXT2FSLIB) || defined (LISTMODE_EDITOR)
     { ' ', "", ' ', 0 },
+#endif
     { ' ', N_("&Extension file edit"),          'E', ext_cmd },
     { ' ', N_("&Menu file edit"),               'M', menu_edit_cmd },
-    {' ',  N_("Menu edi&Tor edit"),             'T', edit_user_menu_cmd}
+#ifdef USE_INTERNAL_EDIT
+    {' ',  N_("Menu edi&Tor edit"),		'T', edit_user_menu_cmd}
+#endif /* USE_INTERNAL_EDIT */
 };
 
 /* Must keep in sync with the constants in menu_cmd */
@@ -1740,10 +1749,12 @@ static const key_map ctl_x_map [] = {
     { XCTRL('p'),   copy_other_pathname },
     { 't',          copy_current_tagged },
     { XCTRL('t'),   copy_other_tagged },
-#endif
     { 'c',          chmod_cmd },
+#endif
 #ifndef OS2_NT
+#ifndef HAVE_GNOME
     { 'o',          chown_cmd },
+#endif
     { 'l',          link_cmd },
     { XCTRL('l'),   other_symlink_cmd },
     { 's',          symlink_cmd },
@@ -2274,33 +2285,6 @@ do_nc (void)
     done_mc_profile ();
 }
 
-#include "features.inc"
-
-static void
-version (int verbose)
-{
-    char *str;    
-
-    fprintf (stderr, "The Midnight Commander %s\n", VERSION);
-    if (!verbose)
-	return;
-    
-#ifndef HAVE_X
-    fprintf (stderr, status_mouse_support ?
-	    _("with mouse support on xterm and the Linux console.\n") :
-	    _("with mouse support on xterm.\n"));
-#endif /* HAVE_X */
-    for (verbose = 0; features [verbose]; verbose++) 
-    	fprintf (stderr, _(features [verbose]));
-
-    str = guess_message_value (1);
-    fprintf (stderr, "%s\n", str);
-    g_free (str);
-
-    if (print_last_wd)
-	write (stdout_fd, ".", 1);
-}
-
 #if defined (_OS_NT)
 /* Windows NT code */
 #define CONTROL_FILE "\\mc.%d.control"
@@ -2489,6 +2473,7 @@ init_sigchld (void)
 #endif
 #endif
 
+#ifndef HAVE_X
 static void
 print_mc_usage (void)
 {
@@ -2572,6 +2557,7 @@ print_color_usage (void)
 	     "   yellow, blue, brightblue, magenta, brightmagenta, cyan,\n"
 	     "   brightcyan, lightgray and white\n\n"));
 }
+#endif /* !HAVE_X */
 
 static void
 probably_finish_program (void)
@@ -2592,6 +2578,7 @@ static void
 process_args (int c, const char *option_arg)
 {
     switch (c) {
+#ifndef HAVE_X
     case 'V':
 	version (1);
 	finish_program = 1;
@@ -2603,6 +2590,7 @@ process_args (int c, const char *option_arg)
 	force_colors = 1;
 #endif
 	break;
+#endif /* !HAVE_X */
 		
     case 'f':
 	fprintf (stderr, _("Library directory for the Midnight Commander: %s\n"), mc_home);
@@ -2664,13 +2652,13 @@ process_args (int c, const char *option_arg)
 #endif
 	break;
 	    
+#ifndef HAVE_X
     case 'H':
 	print_color_usage ();
 	finish_program = 1;
 	break;
 	    
     case 'h':
-#ifndef PORT_WANTS_ARGP
 	print_mc_usage ();
 	finish_program = 1;
 #endif
@@ -2881,15 +2869,17 @@ handle_args (int argc, char *argv [])
 		poptStrerror (c));
 	finish_program = 1;
     }
-#endif
     probably_finish_program ();
+#endif /* HAVE_GNOME */
 
+    tmp = poptGetArg (ctx);
+
+#ifndef HAVE_GNOME
     /*
      * Check for special invocation names mcedit and mcview,
      * if none apply then set the current directory and the other
      * directory from the command line arguments
      */
-    tmp = poptGetArg (ctx);
     base = x_basename (argv[0]);
     if (!STRNCOMP (base, "mce", 3) || !STRCOMP(base, "vi")) {
 	edit_one_file = "";
@@ -2911,7 +2901,14 @@ handle_args (int argc, char *argv [])
     if (!STRNCOMP (base, "mcv", 3) || !STRCOMP(base, "view")) {
 	if (tmp)
 	    view_one_file = g_strdup (tmp);
-    } else {
+	else {
+	    fprintf (stderr, "No arguments given to the viewer\n");
+	    finish_program = 1;
+	    probably_finish_program ();
+ 	}
+    } else
+#endif /* HAVE_GNOME */
+    {
        	/* sets the current dir and the other dir */
 	if (tmp) {
     	    char buffer[MC_MAXPATHLEN + 2];
@@ -3021,7 +3018,6 @@ main (int argc, char *argv [])
     }
     
     vfs_init ();
-    edit_init_file();
     
 #ifdef HAVE_X
     /* NOTE: This call has to be before any our argument handling :) */
@@ -3133,19 +3129,22 @@ main (int argc, char *argv [])
     init_curses ();
 #endif
 
-#ifdef HAVE_GNOME
-    use_subshell = 0;
-#endif
-    
-#   ifdef HAVE_SUBSHELL_SUPPORT
-	/* Done here to ensure that the subshell doesn't  */
-	/* inherit the file descriptors opened below, etc */
+#ifdef HAVE_SUBSHELL_SUPPORT
 
-	if (use_subshell)
-	    init_subshell ();  
-#   endif
+    /* Don't use subshell in GNOME and when invoked as a viewer or editor */
+#ifndef HAVE_GNOME
+    if (edit_one_file || view_one_file)
+#endif /* !HAVE_GNOME */
+	use_subshell = 0;
 
-#   ifndef HAVE_X
+    /* Done here to ensure that the subshell doesn't  */
+    /* inherit the file descriptors opened below, etc */
+    if (use_subshell)
+	init_subshell ();  
+
+#endif /* HAVE_SUBSHELL_SUPPORT */
+
+#ifndef HAVE_X
     /* Removing this from the X code let's us type C-c */
     load_key_defs ();
 
@@ -3155,7 +3154,7 @@ main (int argc, char *argv [])
     
     if (alternate_plus_minus)
         application_keypad_mode ();
-#   endif
+#endif /* !HAVE_X */
 
 #ifdef HAVE_GNOME
     gnome_check_super_user ();
