@@ -5,7 +5,7 @@
    Rewritten by: 1998 Pavel Machek
    Additional changes by: 1999 Andrew T. Veliath
 
-   $Id: extfs.c,v 1.32 2000/01/13 15:15:42 pavel Exp $
+   $Id: extfs.c,v 1.36 2001/02/20 16:55:58 proskin Exp $
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public License
@@ -19,7 +19,7 @@
 
    You should have received a copy of the GNU Library General Public
    License along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
 /* Namespace: exports only vfs_extfs_ops */
 
@@ -37,16 +37,14 @@
 #include <sys/wait.h>
 #endif
 #include <errno.h>
-#ifdef SCO_FLAVOR
-#include <sys/timeb.h>	/* alex: for struct timeb definition */
-#endif /* SCO_FLAVOR */
-#include <time.h>
 #include "utilvfs.h"
 #include "../src/dialog.h"
 #include "../src/main.h"	/* For shell_execute */
+#include "xdirentry.h"
 #include "vfs.h"
 #include "extfs.h"
 
+#undef ERRNOR
 #define ERRNOR(x,y) do { my_errno = x; return y; } while(0)
 
 static struct entry *
@@ -605,7 +603,7 @@ static void *extfs_open (vfs *me, char *file, int flags, int mode)
         char *cmd;
 	char *archive_name, *p;
         
-        entry->inode->local_filename = tempnam (NULL, "extfs");
+        entry->inode->local_filename = g_tempnam (NULL, "extfs");
 	{
 	    int handle;
 
