@@ -17,7 +17,7 @@
 
    You should have received a copy of the GNU Library General Public
    License along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
 /* Namespace: exports smbfs_vfs_ops, tcp_invalidate_socket */
 #include <stdio.h>
@@ -26,7 +26,7 @@
 #include "../config.h"
 #include "samba/include/config.h"
 /* don't load crap in "samba/include/includes.h" we don't use and which 
-   confilcts with definitions in other includes */
+   conflicts with definitions in other includes */
 #undef HAVE_LIBREADLINE
 #define NO_CONFIG_H
 #define BOOL_DEFINED
@@ -466,7 +466,7 @@ smbfs_close (void *data)
     if (archive_level >= 2 && (inf->attr & aARCH)) {
         cli_setatr(info->cli, rname, info->attr & ~(uint16)aARCH, 0);
     }	*/
-	return cli_close(info->cli, info->fnum);
+	return (cli_close(info->cli, info->fnum) == True) ? 0 : -1;
 }
 
 static int
@@ -486,7 +486,7 @@ typedef struct dir_entry {
 typedef struct {
 	gboolean server_list;
 	char *dirname;
-	char *path;	/* the dir orginally passed to smbfs_opendir */
+	char *path;	/* the dir originally passed to smbfs_opendir */
     smbfs_connection *conn;
     dir_entry *entries;
     dir_entry *current;
@@ -512,12 +512,11 @@ browsing_helper(const char *name, uint32 type, const char *comment)
 
 	if (first_direntry) {
 		current_info->entries = new_entry;
-		current_info->current = new_entry;
 		first_direntry = FALSE;
 	} else {
 		current_info->current->next = new_entry;
-		current_info->current = new_entry;
 	}
+	current_info->current = new_entry;
 
 	bzero(&new_entry->my_stat, sizeof(struct stat));
 	new_entry->merrno = 0;
@@ -654,7 +653,7 @@ reconnect(smbfs_connection *conn, int *retries) {
 	char *host;
 	DEBUG(3, ("RECONNECT\n"));
 
-	if (strlen(conn->host) == 0)
+	if (*(conn->host) == 0)
 		host = g_strdup(conn->cli->desthost);		/* server browsing */
 	else
 		host = g_strdup(conn->host);
@@ -752,14 +751,14 @@ chkpath(struct cli_state *cli, char *path, BOOL send_only)
 
 /* #if 0 */
 static int
-fs (char *text)
+fs (const char *text)
 {
-	char *p, count = 0;
-	p = strchr(text, '/');
-	while (p) {
+	const char *p = text;
+	int count = 0;
+	
+	while ((p = strchr(p, '/')) != NULL) {
 		count++;
 		p++;
-		p = strchr(p, '/');
 	}
 	if (count == 1)
 		return strlen(text);
@@ -1128,9 +1127,9 @@ smbfs_get_free_bucket ()
 		if (!smbfs_connections [i].cli) return &smbfs_connections [i];
 
 	{	/* search for most dormant connection */
-		int oldest;	/* index */
+		int oldest = 0;	/* index */
 		time_t oldest_time = time(NULL);
-		for (i = 0; i< SMBFS_MAX_CONNECTIONS; i++) {
+		for (i = 0; i < SMBFS_MAX_CONNECTIONS; i++) {
 			if (smbfs_connections[i].last_use < oldest_time) {
 				oldest_time = smbfs_connections[i].last_use;
 				oldest = i;
@@ -1153,8 +1152,8 @@ smbfs_open_link(char *host, char *path, char *user, int *port, char *this_pass)
 {
     int i;
     smbfs_connection *bucket;
-	pstring service;
-	struct in_addr *dest_ip = NULL;
+    pstring service;
+    struct in_addr *dest_ip = NULL;
 
 	DEBUG(3, ("smbfs_open_link(host:%s, path:%s)\n", host, path));
 
@@ -1164,7 +1163,8 @@ smbfs_open_link(char *host, char *path, char *user, int *port, char *this_pass)
 		char *p;
 		if ((p = strchr(path, '/')))	/* get share aka				*/
 			pstrcpy(service, ++p);	/* service name from path		*/
-
+		else
+			pstrcpy(service, "");
 		/* now check for trailing directory/filenames	*/
 		p = strchr(service, '/');
 		if (p)
@@ -1227,16 +1227,15 @@ smbfs_open_link(char *host, char *path, char *user, int *port, char *this_pass)
 		bucket->host = g_strdup(host);
 
 	if (!bucket_set_authinfo (bucket,
-				  0,      /* domain not currently not used */
+				  0,      /* domain currently not used */
 				  user, 
 				  this_pass, 
 				  1))
 		return 0;
 
 	/* connect to share */
-    for ( ;; ) {
-        if (bucket->cli = do_connect(host, service))
-		break;
+    while (!(bucket->cli = do_connect(host, service))) {
+
 	if (my_errno != EPERM)
             return 0;
 	message_1s (1, MSG_ERROR,
@@ -1798,13 +1797,13 @@ smbfs_free (vfsid id)
 	authinfo_free_all ();
 }
 
-/* Gives up on a socket and reopnes the connection, the child own the socket
+/* Gives up on a socket and reopens the connection, the child own the socket
  * now
  */
 static void
 my_forget (char *path)
 {
-    char *host, *user, *pass, *p;
+    char *host, *user, *p;
     int  port, i;
 
     if (strncmp (path, URL_HEADER, HEADER_LEN))
@@ -1816,14 +1815,13 @@ my_forget (char *path)
     if (path[0] == '/' && path[1] == '/')
 	path += 2;
 
-    if ((p = smbfs_get_host_and_username (&path, &host, &user, &port, &pass))
+    if ((p = smbfs_get_host_and_username (&path, &host, &user, &port, NULL))
 		== 0) {
 		g_free (host);
 		g_free (user);
-		if (pass)
-		    wipe_password (pass);
 		return;
     }
+    g_free (p);
     for (i = 0; i < SMBFS_MAX_CONNECTIONS; i++) {
 		if ((strcmp (host, smbfs_connections [i].host) == 0) &&
 		    (strcmp (user, smbfs_connections [i].user) == 0) &&
@@ -1837,11 +1835,8 @@ my_forget (char *path)
 				do_connect(host, smbfs_connections[i].service);
 		}
     }
-    g_free (p);
     g_free (host);
     g_free (user);
-    if (pass)
-		wipe_password (pass);
 }
 
 static int 
@@ -1995,7 +1990,7 @@ smbfs_fstat (void *data, struct stat *buf)
 
 vfs vfs_smbfs_ops = {
     NULL,	/* This is place of next pointer */
-    "netbios over tcp/ip",
+    N_("netbios over tcp/ip"),
     F_NET,	/* flags */
     "smb:",	/* prefix */
     NULL,	/* data */
